@@ -4,7 +4,7 @@
 # SPDX-License-Identifier: GPL-2.0-or-later
 #
 # This file is part of the program "Back In Time" which is released under GNU
-# General Public License v2 (GPLv2). See file/folder LICENSE or go to
+# General Public License v2 (GPLv2). See LICENSES directory or go to
 # <https://spdx.org/licenses/GPL-2.0-or-later.html>.
 """Tests about config module.
 """
@@ -113,40 +113,6 @@ class SshCommand(generic.SSHTestCase):
             ]
         )
 
-    def test_cipher_aes256_cbc(self):
-        self.cfg.setSshCipher('aes256-cbc')
-        cmd = self.cfg.sshCommand(cmd=['echo', 'foo'])
-
-        self.assertListEqual(
-            cmd,
-            [
-                'ssh',
-                '-o', 'ServerAliveInterval=240',
-                '-o', 'LogLevel=Error',
-                '-o', f'IdentityFile={generic.PRIV_KEY_FILE}',
-                '-p', '22',
-                '-o', 'Ciphers=aes256-cbc',
-                f'{self._user}@localhost',
-                'echo', 'foo'
-            ]
-        )
-
-    def test_cipher_disabled(self):
-        cmd = self.cfg.sshCommand(cmd=['echo', 'foo'], cipher=False)
-
-        self.assertListEqual(
-            cmd,
-            [
-                'ssh',
-                '-o', 'ServerAliveInterval=240',
-                '-o', 'LogLevel=Error',
-                '-o', f'IdentityFile={generic.PRIV_KEY_FILE}',
-                '-p', '22',
-                f'{self._user}@localhost',
-                'echo', 'foo'
-            ]
-        )
-
     def test_without_command(self):
         cmd = self.cfg.sshCommand()
         self.assertListEqual(
