@@ -9,20 +9,16 @@
 # General Public License v2 (GPLv2). See LICENSES directory or go to
 # <https://spdx.org/licenses/GPL-2.0-or-later.html>.
 import os
-import sys
 import unittest
 import stat
 from datetime import date, datetime
 from test import generic
-from unittest.mock import patch
-
-sys.path.append(os.path.join(os.path.dirname(__file__), '..'))
 import configfile
 import snapshots
-from snapshotlog import LogFilter, SnapshotLog
+from snapshotlog import SnapshotLog
 
 
-class TestSID(generic.SnapshotsTestCase):
+class General(generic.SnapshotsTestCase):
     def test_new_object_with_valid_date(self):
         sid1 = snapshots.SID('20151219-010324-123', self.cfg)
         sid2 = snapshots.SID('20151219-010324', self.cfg)
@@ -137,16 +133,21 @@ class TestSID(generic.SnapshotsTestCase):
     def test_path(self):
         sid = snapshots.SID('20151219-010324-123', self.cfg)
 
-        self.assertEqual(sid.path(),
-                         os.path.join(self.snapshotPath, '20151219-010324-123'))
-        self.assertEqual(sid.path('foo', 'bar', 'baz'),
-                         os.path.join(self.snapshotPath,
-                                      '20151219-010324-123',
-                                      'foo', 'bar', 'baz'))
+        self.assertEqual(
+            sid.path(),
+            os.path.join(self.snapshotPath, '20151219-010324-123'))
+
+        self.assertEqual(
+            sid.path('foo', 'bar', 'baz'),
+            os.path.join(self.snapshotPath,
+                         '20151219-010324-123',
+                         'foo', 'bar', 'baz'))
+
         self.assertEqual(sid.pathBackup(),
                          os.path.join(self.snapshotPath,
                                       '20151219-010324-123',
                                       'backup'))
+
         self.assertEqual(sid.pathBackup('/foo'),
                          os.path.join(self.snapshotPath,
                                       '20151219-010324-123',
@@ -226,7 +227,8 @@ class TestSID(generic.SnapshotsTestCase):
     def test_lastChecked(self):
         sid = snapshots.SID('20151219-010324-123', self.cfg)
         os.makedirs(os.path.join(self.snapshotPath, '20151219-010324-123'))
-        infoFile = os.path.join(self.snapshotPath, '20151219-010324-123', 'info')
+        infoFile = os.path.join(
+            self.snapshotPath, '20151219-010324-123', 'info')
 
         #no info file
         self.assertEqual(sid.lastChecked, '2015-12-19 01:03:24')
@@ -241,7 +243,8 @@ class TestSID(generic.SnapshotsTestCase):
         #setLastChecked and check if it matches current date
         sid.setLastChecked()
         now = datetime.now()
-        self.assertRegex(sid.lastChecked, now.strftime(r'%Y-%m-%d %H:%M:\d{2}'))
+        self.assertRegex(sid.lastChecked,
+                         now.strftime(r'%Y-%m-%d %H:%M:\d{2}'))
 
     def test_failed(self):
         sid = snapshots.SID('20151219-010324-123', self.cfg)
@@ -262,7 +265,8 @@ class TestSID(generic.SnapshotsTestCase):
     def test_info(self):
         sid1 = snapshots.SID('20151219-010324-123', self.cfg)
         os.makedirs(os.path.join(self.snapshotPath, '20151219-010324-123'))
-        infoFile = os.path.join(self.snapshotPath, '20151219-010324-123', 'info')
+        infoFile = os.path.join(
+            self.snapshotPath, '20151219-010324-123', 'info')
 
         i1 = configfile.ConfigFile()
         i1.setStrValue('foo', 'bar')
@@ -278,92 +282,6 @@ class TestSID(generic.SnapshotsTestCase):
         i2 = sid2.info
         self.assertEqual(i2.strValue('foo', 'default'), 'bar')
 
-    def test_fileInfo(self):
-        sid1 = snapshots.SID('20151219-010324-123', self.cfg)
-        os.makedirs(os.path.join(self.snapshotPath, '20151219-010324-123'))
-        infoFile = os.path.join(self.snapshotPath,
-                                '20151219-010324-123',
-                                'fileinfo.bz2')
-
-        d = snapshots.FileInfoDict()
-        d[b'/tmp']     = (123, b'foo', b'bar')
-        d[b'/tmp/foo'] = (456, b'asdf', b'qwer')
-        sid1.fileInfo = d
-
-        self.assertIsFile(infoFile)
-
-        #load fileInfo in a new snapshot
-        sid2 = snapshots.SID('20151219-010324-123', self.cfg)
-        self.assertDictEqual(sid2.fileInfo, d)
-
-    @patch('logger.error')
-    def test_fileInfoErrorRead(self, mock_logger):
-        sid = snapshots.SID('20151219-010324-123', self.cfg)
-        os.makedirs(os.path.join(self.snapshotPath, '20151219-010324-123'))
-        infoFile = sid.path(sid.FILEINFO)
-        # remove all permissions from file
-        with open(infoFile, 'wt'):
-            pass
-
-        with generic.mockPermissions(infoFile):
-            self.assertEqual(sid.fileInfo, snapshots.FileInfoDict())
-            self.assertTrue(mock_logger.called)
-
-    @patch('logger.error')
-    def test_fileInfoErrorWrite(self, mock_logger):
-        sid = snapshots.SID('20151219-010324-123', self.cfg)
-        os.makedirs(os.path.join(self.snapshotPath, '20151219-010324-123'))
-        infoFile = sid.path(sid.FILEINFO)
-        # remove all permissions from file
-        with open(infoFile, 'wt'):
-            pass
-
-        with generic.mockPermissions(infoFile):
-            d = snapshots.FileInfoDict()
-            d[b'/tmp']     = (123, b'foo', b'bar')
-            d[b'/tmp/foo'] = (456, b'asdf', b'qwer')
-            sid.fileInfo = d
-            self.assertTrue(mock_logger.called)
-
-    def test_log(self):
-        sid = snapshots.SID('20151219-010324-123', self.cfg)
-        os.makedirs(os.path.join(self.snapshotPath, '20151219-010324-123'))
-        logFile = os.path.join(self.snapshotPath,
-                               '20151219-010324-123',
-                               'takesnapshot.log.bz2')
-
-        #no log available
-        self.assertRegex('\n'.join(sid.log()), r'Failed to get snapshot log from.*')
-
-        sid.setLog('foo bar\nbaz')
-        self.assertIsFile(logFile)
-
-        self.assertEqual('\n'.join(sid.log()), 'foo bar\nbaz')
-
-    def test_log_filter(self):
-        sid = snapshots.SID('20151219-010324-123', self.cfg)
-        os.makedirs(os.path.join(self.snapshotPath, '20151219-010324-123'))
-        logFile = os.path.join(self.snapshotPath,
-                               '20151219-010324-123',
-                               'takesnapshot.log.bz2')
-
-        sid.setLog('foo bar\n[I] 123\n[C] baz\n[E] bla')
-        self.assertIsFile(logFile)
-
-        self.assertEqual('\n'.join(sid.log(mode = LogFilter.CHANGES)), 'foo bar\n[C] baz')
-
-    def test_setLog_binary(self):
-        sid = snapshots.SID('20151219-010324-123', self.cfg)
-        os.makedirs(os.path.join(self.snapshotPath, '20151219-010324-123'))
-        logFile = os.path.join(self.snapshotPath,
-                               '20151219-010324-123',
-                               'takesnapshot.log.bz2')
-
-        sid.setLog(b'foo bar\nbaz')
-        self.assertIsFile(logFile)
-
-        self.assertEqual('\n'.join(sid.log()), 'foo bar\nbaz')
-
     def test_makeWritable(self):
         sid = snapshots.SID('20151219-010324-123', self.cfg)
         sidPath = os.path.join(self.snapshotPath,   '20151219-010324-123')
@@ -387,7 +305,7 @@ class TestSID(generic.SnapshotsTestCase):
             self.fail(msg.format(testFile))
 
 
-class TestNewSnapshot(generic.SnapshotsTestCase):
+class NewBackup(generic.SnapshotsTestCase):
     def test_create_new(self):
         new = snapshots.NewSnapshot(self.cfg)
         self.assertFalse(new.exists())
@@ -398,7 +316,7 @@ class TestNewSnapshot(generic.SnapshotsTestCase):
                                                    new.NEWSNAPSHOT,
                                                    'backup')))
 
-    def test_saveToContinue(self):
+    def test_save_to_continue(self):
         new = snapshots.NewSnapshot(self.cfg)
         snapshotPath = os.path.join(self.snapshotPath, new.NEWSNAPSHOT)
         saveToContinuePath = os.path.join(snapshotPath, new.SAVETOCONTINUE)
@@ -415,7 +333,7 @@ class TestNewSnapshot(generic.SnapshotsTestCase):
         self.assertNotExists(saveToContinuePath)
         self.assertFalse(new.saveToContinue)
 
-    def test_hasChanges(self):
+    def test_has_changes(self):
         now = datetime(2016, 7, 10, 16, 24, 17)
 
         new = snapshots.NewSnapshot(self.cfg)
@@ -433,7 +351,7 @@ class TestNewSnapshot(generic.SnapshotsTestCase):
         self.assertTrue(new.hasChanges)
 
 
-class TestRootSnapshot(generic.SnapshotsTestCase):
+class RootBackup(generic.SnapshotsTestCase):
     #TODO: add test with 'sid.path(use_mode=['ssh_encfs'])'
     def test_create(self):
         sid = snapshots.RootSnapshot(self.cfg)
@@ -447,9 +365,9 @@ class TestRootSnapshot(generic.SnapshotsTestCase):
         self.assertEqual(sid.path('foo', 'bar'), '/foo/bar')
 
 
-class TestIterSnapshots(generic.SnapshotsTestCase):
+class IterBackups(generic.SnapshotsTestCase):
     def setUp(self):
-        super(TestIterSnapshots, self).setUp()
+        super().setUp()
 
         for i in ('20151219-010324-123',
                   '20151219-020324-123',
@@ -465,7 +383,7 @@ class TestIterSnapshots(generic.SnapshotsTestCase):
                                   '20151219-010324-123'])
         self.assertIsInstance(l1[0], snapshots.SID)
 
-    def test_list_new_snapshot(self):
+    def test_list_new(self):
         os.makedirs(os.path.join(self.snapshotPath, 'new_snapshot', 'backup'))
         l2 = snapshots.listSnapshots(self.cfg, includeNewSnapshot = True)
         self.assertListEqual(l2, ['new_snapshot',
@@ -476,7 +394,7 @@ class TestIterSnapshots(generic.SnapshotsTestCase):
         self.assertIsInstance(l2[0], snapshots.NewSnapshot)
         self.assertIsInstance(l2[-1], snapshots.SID)
 
-    def test_list_snapshot_without_backup(self):
+    def test_list_without_backup(self):
         #new snapshot without backup folder shouldn't be added
         os.makedirs(os.path.join(self.snapshotPath, '20151219-050324-123'))
         l3 = snapshots.listSnapshots(self.cfg)
@@ -485,18 +403,19 @@ class TestIterSnapshots(generic.SnapshotsTestCase):
                                   '20151219-020324-123',
                                   '20151219-010324-123'])
 
-    def test_list_invalid_snapshot(self):
-        #invalid snapshot shouldn't be added
+    def test_list_invalid(self):
+        # invalid snapshot shouldn't be added
         os.makedirs(os.path.join(self.snapshotPath,
                                  '20151219-000324-abc',
                                  'backup'))
+
         l4 = snapshots.listSnapshots(self.cfg)
         self.assertListEqual(l4, ['20151219-040324-123',
                                   '20151219-030324-123',
                                   '20151219-020324-123',
                                   '20151219-010324-123'])
 
-    def test_list_without_new_snapshot(self):
+    def test_list_without_new_backup(self):
         os.makedirs(os.path.join(self.snapshotPath, 'new_snapshot', 'backup'))
         l5 = snapshots.listSnapshots(self.cfg, includeNewSnapshot = False)
         self.assertListEqual(l5, ['20151219-040324-123',
@@ -504,7 +423,7 @@ class TestIterSnapshots(generic.SnapshotsTestCase):
                                   '20151219-020324-123',
                                   '20151219-010324-123'])
 
-    def test_list_symlink_last_snapshot(self):
+    def test_list_symlink_last_backup(self):
         os.symlink('./20151219-040324-123',
                    os.path.join(self.snapshotPath, 'last_snapshot'))
         l6 = snapshots.listSnapshots(self.cfg)
@@ -526,29 +445,32 @@ class TestIterSnapshots(generic.SnapshotsTestCase):
         self.assertIsInstance(l7[0], snapshots.SID)
         self.assertIsInstance(l7[-1], snapshots.NewSnapshot)
 
-    def test_iter_snapshots(self):
-        for i, sid in enumerate(snapshots.iterSnapshots(self.cfg)):
+    def test_iter(self):
+        count = 0
+        for sid in snapshots.iterSnapshots(self.cfg):
+            count += 1
             self.assertIn(sid, ['20151219-040324-123',
                                 '20151219-030324-123',
                                 '20151219-020324-123',
                                 '20151219-010324-123'])
             self.assertIsInstance(sid, snapshots.SID)
-        self.assertEqual(i, 3)
 
-    def test_lastSnapshot(self):
+        self.assertEqual(count, 4)
+
+    def test_last(self):
         self.assertEqual(snapshots.lastSnapshot(self.cfg),
                          '20151219-040324-123')
 
 
-class TestIterSnapshotsNonexistingSnapshotPath(generic.TestCaseSnapshotPath):
-    def test_iterSnapshots(self):
+class IterBackupsNonexistingBackupPath(generic.TestCaseSnapshotPath):
+    def test_iter(self):
         for _ in snapshots.iterSnapshots(self.cfg):
             self.fail('got unexpected snapshot')
 
-    def test_listSnapshots(self):
+    def test_list(self):
         self.assertEqual(snapshots.listSnapshots(self.cfg), [])
 
-    def test_lastSnapshots(self):
+    def test_last(self):
         self.assertIsNone(snapshots.lastSnapshot(self.cfg))
 
 
