@@ -12,7 +12,7 @@ CURRENT=$(pwd)
 NEW="backintime-$VER"
 
 # clean up
-rm ./common/man/C/*.gz
+rm ./doc/manpages/*.gz
 
 cd ..
 
@@ -23,9 +23,6 @@ cd ..
 # fi
 
 cp -aR ${CURRENT} ${NEW}
-rm -rf ${NEW}/.git
-rm -rf ${NEW}/.github
-rm -rf ${NEW}/.pytest_cache
 
 rm backintime-$VER.tar.gz
 
@@ -37,14 +34,16 @@ tar cfz backintime-$VER.tar.gz \
     --exclude-vcs \
     ${NEW}/AUTHORS \
     ${NEW}/CHANGES \
-    ${NEW}/LICENSE \
-    ${NEW}/README.md \
-    ${NEW}/FAQ.md \
     ${NEW}/CONTRIBUTING.md \
+    ${NEW}/FAQ.md \
     ${NEW}/HISTORY.md \
-    ${NEW}/TRANSLATIONS \
+    ${NEW}/LICENSES.md \
+    ${NEW}/README.md \
+    ${NEW}/REUSE.toml \
     ${NEW}/VERSION \
     ${NEW}/updateversion.sh \
+    ${NEW}/update_language_files.py \
+    ${NEW}/create-manpage-backintime-config.py \
     ${NEW}/common \
     ${NEW}/qt \
     ${NEW}/LICENSES \
@@ -55,5 +54,5 @@ echo ""
 echo "RESULT:"
 realpath backintime-$VER.tar.gz
 
-rm -rf ${NEW}
+rm -rf backintime-$VER
 
