@@ -3,7 +3,7 @@
 # SPDX-License-Identifier: GPL-2.0-or-later
 #
 # This file is part of the program "Back In time" which is released under GNU
-# General Public License v2 (GPLv2). See file/folder LICENSE or go to
+# General Public License v2 (GPLv2). See LICENSES directory or go to
 # <https://spdx.org/licenses/GPL-2.0-or-later.html>.
 """Tests using several linters.
 
@@ -37,18 +37,57 @@ ANY_LINTER_AVAILABLE = any((
 # "qt" directory
 _base_dir = pathlib.Path(__file__).resolve().parent.parent
 
+"""
+
+"""
 # Files in this lists will get the full battery of linters and rule sets.
 full_test_files = [_base_dir / fp for fp in (
     'aboutdlg.py',
+    # 'app.py',
+    'bitwidgets.py',
+    'confirmrestoredialog.py',
+    'editusercallback.py',
     'encfsmsgbox.py',
+    'filedialog.py',
+    # 'icon.py',
+    'languagedialog.py',
+    'logviewdialog.py',
+    'manageprofiles/__init__.py',
     'manageprofiles/combobox.py',
-    'manageprofiles/statebindcheckbox.py',
+    'manageprofiles/copylinkswidget.py',
+    'manageprofiles/excludesuggestions.py',
     'manageprofiles/schedulewidget.py',
+    'manageprofiles/sectionedchecklist.py',
+    'manageprofiles/sshkeyselector.py',
+    'manageprofiles/spinboxunit.py',
+    'manageprofiles/statebindcheckbox.py',
+    'manageprofiles/storagesizewidget.py',
     'manageprofiles/sshproxywidget.py',
+    'manageprofiles/tab_exclude.py',
+    'manageprofiles/tab_expert_options.py',
+    'manageprofiles/tab_general.py',
+    'manageprofiles/tab_include.py',
+    'manageprofiles/tab_options.py',
+    'manageprofiles/tab_remove_retention.py',
+    'messagebox.py',
+    'placeswidget.py',
     'plugins/notifyplugin.py',
+    'plugins/systrayiconplugin.py',
+    # 'qtsystrayicon.py',
+    'qttools.py',
+    'qttools_path.py',
+    'restoreconfigdialog.py',
+    'restoredialog.py',
+    # 'serviceHelper.py',
+    'shutdowndlg.py',
+    # 'snapshotsdialog.py',
     'statedata.py',
+    'statusbar.py',
+    'test/__init__.py',
     'test/test_lint.py',
     'test/test_statedata.py',
+    'textdlg.py',
+    'timeline.py',
     'usermessagedialog.py',
 )]
 
@@ -83,8 +122,7 @@ def create_pylint_cmd(include_error_codes=None):
         # PEP8 conform line length (see PyLint Issue #3078)
         f'--max-line-length={PEP8_MAX_LINE_LENGTH}',
         # Whitelist variable names
-        '--good-names=idx,fp',
-        # '--reports=yes',
+        '--good-names=idx,fp,closeEvent',
     ]
 
     if include_error_codes:
@@ -163,7 +201,7 @@ class MirrorMirrorOnTheWall(unittest.TestCase):
                 f'be {version_target} or higher.')
 
         if RUFF_AVAILABLE:
-            version_target = version.parse('0.6.0')
+            version_target = version.parse('0.15.0')
 
             proc = subprocess.run(
                 ['ruff', '--version'],
@@ -192,7 +230,10 @@ class MirrorMirrorOnTheWall(unittest.TestCase):
             # - PyCodestyle (E, W)
             # - flake8-gettext (INT)
             # - useless noqua (RUF100)
-            '--extend-select=PL,E,W,INT,RUF100',
+            # - pep8-naming (N)
+            # Consider UP, ANN, D, DOC (upgrade, annotation, pydocstyle,
+            # pydoclint)
+            '--extend-select=PL,E,W,INT,RUF100,N',
             # Ignore: redefined-loop-name
             '--ignore=PLW2901',
             '--line-length', str(PEP8_MAX_LINE_LENGTH),
@@ -284,7 +325,7 @@ class MirrorMirrorOnTheWall(unittest.TestCase):
         self.assertEqual(r.stderr, '')
 
     @unittest.skipUnless(PYLINT_AVAILABLE, BASE_REASON.format('PyLint'))
-    def test050_pylint_exclusive_ruleset(self):
+    def test050_pylint_reduced_ruleset(self):
         """Use Pylint to check for specific rules only.
 
         Some facts about PyLint
@@ -294,10 +335,21 @@ class MirrorMirrorOnTheWall(unittest.TestCase):
 
         # Explicit activate checks
         err_codes = [
+            # 'C0103',  # invalid-name
+            'C0114',  # missing-module-docstring
+            'C0115',  # missing-class-docstring
+            # 'C0116',  # missing-function-docstring
+            'C0200',  # consider-using-enumerate
+            'C0201',  # consider-iterating-dictionary
+            'C0301',  # line-too-long
+            'C0303',  # trailing-whitespace
             'C0305',  # trailing-newlines
+            'C0321',  # multiple-statements
             'C0325',  # superfluous-parens
             'C0410',  # multiple-imports
-            'C0303',  # trailing-whitespace
+            # 'C0411',  # wrong-import-order
+            # 'C0412',  # ungouped-imports
+            # 'C0413',  # wrong-import-position
             'E0100',  # init-is-generator
             'E0101',  # return-in-init
             'E0102',  # function-redefined
@@ -307,30 +359,63 @@ class MirrorMirrorOnTheWall(unittest.TestCase):
             'E0401',  # import-error
             'E0602',  # undefined-variable
             'E1101',  # no-member
+            'E1120',  # no-value-for-parameter
+            'E1121',  # too-many-function-args
+            'E1123',  # unexpected-keyword-arg
+            'E1129',  # not-context-manager
             'I0021',  # useless-suppression
+            'R0202',  # no-classmethod-decorator
+            'R0203',  # no-staticmethod-decorator
+            'R0801',  # duplicate-code
+            # 'R0902',  # too-many-instance-attributes
+            'R0904',  # too-many-public-methods
+            'R0912',  # too-many-branches
+            'R0913',  # too-many-arguments
+            # 'R0915',  # too-many-statements
+            'W0101',  # unreachable
+            # 'W0102',  # dangerous-default-value
+            'W0105',  # pointless-string-statement
+            'W0106',  # expression-not-assigned
+            'W0107',  # unnecessary-pass
+            # 'W0120',  # useless-else-on-loop
+            'w0122',  # exec-used
+            'W0123',  # eval-used
+            'W0150',  # lost-exception
+            'W0201',  # attribute-defined-outside-init
+            'W0221',  # arguments-differ
+            'W0237',  # arguments-renamed
             'W0311',  # bad-indentation
+            'W0404',  # reimported
+            'W0603',  # global-statement
             'W0611',  # unused-import
+            'W0612',  # unused-variable
+            'W0613',  # unused-argument
+            'W0614',  # unused-wildcard-import
+            # 'W0621',  # redefined-outer-name
+            # 'W0622',  # redefined-builtin
+            'W0631',  # undefinied-loop-variable
+            # 'W0640',  # cell-var-from-loop
+            'W0702',  # bare-except
+            # 'W0703',  # broad-except
+            'W0707',  # raise-missing-from
+            'W0711',  # binary-op-exception
+            'W1115',  # bad-format-string-key
             'W1301',  # unused-format-string-key
             'W1401',  # anomalous-backslash-in-string (invalid escape sequence)
+            'W1511',  # bad-thread-instantiation
             'W1515',  # forgotten-debug-statement
-
-            # Enable asap. This list is selection of existing (not all!)
-            # problems currently exiting in the BIT code base. Quit easy to fix
-            # because there count is low.
-            # 'R0202',  # no-classmethod-decorator
-            # 'R0203',  # no-staticmethod-decorator
-            'R0801',  # duplicate-code
-            # 'W0123',  # eval-used
-            # 'W0237',  # arguments-renamed
-            # 'W0221',  # arguments-differ
-            # 'W0404',  # reimported
             # 'W4902',  # deprecated-method
+            # 'W4903',  # deprecated-argument
             # 'W4904',  # deprecated-class
-            # 'W0603',  # global-statement
-            # 'W0614',  # unused-wildcard-import
-            # 'W0611',  # unused-import
-            # 'W0612',  # unused-variable
-            # 'W0707',  # raise-missing-from
+            'R0202',  # no-classmethod-decorator
+            'R0203',  # no-staticmethod-decorator
+            # 'R0911',  # too-many-return-statements
+            # 'R0914',  # too-many-locals
+            'R1701',  # simplifiable-if-statement
+            'R1702',  # too-many-nested-blocks
+            'R1703',  # simplifiable-if-expression
+            # 'R1705',  # no-else-return
+            # 'R1720',  # no-else-raise
         ]
 
         cmd = create_pylint_cmd(err_codes)
