@@ -3,8 +3,8 @@
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 #
-# This file is part of the program "Back In time" which is released under GNU
-# General Public License v2 (GPLv2). See file/folder LICENSE or go to
+# This file is part of the program "Back In Time" which is released under GNU
+# General Public License v2 (GPLv2). See LICENSES directory or go to
 # <https://spdx.org/licenses/GPL-2.0-or-later.html>.
 """This helper script does manage transferring translations to and from the
 translation platform (currently Weblate).
@@ -15,9 +15,11 @@ import re
 import tempfile
 import string
 import shutil
+import json
 from pathlib import Path
 from subprocess import run, check_output
-from common import languages
+from lxml import etree
+from common import languages, version
 
 try:
     import polib
@@ -31,12 +33,21 @@ except ImportError:
 LOCAL_DIR = Path('common') / 'po'
 TEMPLATE_PO = LOCAL_DIR / 'messages.pot'
 LANGUAGE_NAMES_PY = Path('common') / 'languages.py'
+GUI_DIR = Path('qt')
+DESKTOP_FILE_FIELDS = ['GenericName', 'Comment']
 WEBLATE_URL = 'https://translate.codeberg.org/git/backintime/common'
 PACKAGE_NAME = 'Back In Time'
-PACKAGE_VERSION = Path('VERSION').read_text('utf-8').strip()
+PACKAGE_VERSION = version.__version__
 BUG_ADDRESS = 'https://github.com/bit-team/backintime'
 # RegEx pattern: Character & followed by a word character (extract as group)
 REX_SHORTCUT_LETTER = re.compile(r'&(\w)')
+TRANSLATION_PLACEHOLDER_MSGID = 'translator-credits-placeholder'
+DEFAULT_COPYRIGHT = '© 2008 Back In Time Team <bit-dev@python.org>'
+MISSING_TRANSLATORS_TXT = "Strict and accurate recording of translators' " \
+    "names began around 2022. As\n" \
+    "the project started in 2008, some earlier translators' names " \
+    'may not have\n' \
+    'been documented and could be lost.'
 
 
 def dict_as_code(a_dict: dict, indent_level: int) -> list[str]:
@@ -115,6 +126,116 @@ def update_po_template():
     print(f'Execute "{cmd}".')
     run(cmd, check=True)
 
+    _update_po_template_from_polkit_policies()
+
+    _update_po_template_from_desktop_files()
+
+    _add_spdx_header_to_po_template()
+
+
+def _add_spdx_header_to_po_template():
+    print(f'Add SPDX Header to PO template file "{TEMPLATE_PO}" …')
+
+    # Header comment with SPDX data
+    spdx_base = get_spdx_metadata_lines(ignore_copyright=True,
+                                        without_comment_prefix=True)
+
+    copyright = f'SPDX-FileCopyrightText: {DEFAULT_COPYRIGHT}'
+
+    pof =  polib.pofile(TEMPLATE_PO)
+
+    print(f'\n{len(pof)} entries in {TEMPLATE_PO}')
+
+    pof.header = f'{DEFAULT_COPYRIGHT}\n{spdx_base}\n{MISSING_TRANSLATORS_TXT}'
+    pof.save()
+
+
+def _update_po_template_from_polkit_policies():
+    """Extract translatable strings from polkit related policy files.
+
+    Policy files are XML content. Translatable strings are marked by
+    an "gettext-domain" attribute. That strings are used in the
+    password request dialogs used by polkit agents; e.g. when starting
+    BIT in root mode or modifying Udev rules.
+    """
+
+    path = Path.cwd() / 'qt'
+
+    for policy_fp in path.glob('*.policy'):
+        print(
+            f'Update PO template file with policy strings from {policy_fp} …')
+
+        parser = etree.XMLParser(remove_comments=False)
+        tree = etree.parse(policy_fp, parser)
+        root = tree.getroot()
+
+        # All tags containing attribute "gettext-domin='backintime'"
+        for elem in root.xpath(".//*[@gettext-domain='backintime']"):
+            # ignore empty fields
+            if not elem.text:
+                continue
+
+            # Add to messages.pot, consider duplicates and location/occurrence
+            _add_entry_to_po_template(
+                msgid=elem.text.strip(),
+                fp=policy_fp.relative_to(Path.cwd()),
+                linenr=elem.sourceline
+            )
+
+
+def _update_po_template_from_desktop_files():
+    # Each qt/*.desktop file
+    for desktop_fp in all_desktop_files_in_qt_dir():
+        print(f'Update PO template file with strings from {desktop_fp} …')
+        content = desktop_fp.read_text(encoding='utf-8')
+
+        for idx, line in enumerate(content.split('\n'), start=1):
+
+            # ignore comments
+            if line.startswith('#'):
+                continue
+
+            try:
+                field, value = line.split('=', 1)
+            except ValueError:
+                continue
+
+            if field not in DESKTOP_FILE_FIELDS:
+                continue
+
+            _add_entry_to_po_template(
+                msgid=value,
+                fp=desktop_fp,
+                linenr=idx
+            )
+
+
+def _add_entry_to_po_template(msgid: str,
+                              fp: Path,
+                              linenr: int):
+
+    po_file = polib.pofile(TEMPLATE_PO)
+
+    entry = po_file.find(msgid)
+    location = (fp, linenr)
+
+    if entry:
+        # Update location
+        if location not in entry.occurrences:
+            entry.occurrences.append(location)
+
+    else:
+        # Add new entry
+        po_file.append(
+            polib.POEntry(
+                msgid=msgid,
+                msgstr='',
+                occurrences=[location],
+            )
+        )
+
+    po_file.save(TEMPLATE_PO)
+
 
 def update_po_language_files(remove_obsolete_entries: bool = False):
     """The po files are updated with the source strings from the pot-file (the
@@ -122,7 +243,7 @@ def update_po_language_files(remove_obsolete_entries: bool = False):
 
     The GNU gettext utility ``msgmerge`` is used for that.
 
-    The function `update_po_template()` should be called before.
+    Make sure that the function `update_po_template()` is called beforehand.
     """
 
     print(
@@ -130,6 +251,9 @@ def update_po_language_files(remove_obsolete_entries: bool = False):
         + ' and remove obsolete entries' if remove_obsolete_entries else ''
     )
 
+    spdx_base = get_spdx_metadata_lines(ignore_copyright=True,
+                                        without_comment_prefix=True)
+
     # Recursive all po-files
     for po_path in LOCAL_DIR.rglob('**/*.po'):
 
@@ -157,6 +281,131 @@ def update_po_language_files(remove_obsolete_entries: bool = False):
             ]
             run(cmd, check=True)
 
+        _set_header(po_path, spdx_base)
+
+
+def update_desktop_files():
+    for desktop_fp in all_desktop_files_in_qt_dir():
+        print(f'Update desktop file {desktop_fp} with translations …')
+        content = desktop_fp.read_text(encoding='utf-8')
+        content = content.split('\n')
+
+        to_translate = {key: None for key in DESKTOP_FILE_FIELDS}
+
+        # iterate from the end to the start
+        for idx, line in reversed(list(enumerate(content[:]))):
+
+            # ignore comments
+            if line.startswith('#'):
+                continue
+
+            # blank line?
+            if not line:
+                content = content[:idx] + content[idx+1:]
+                continue
+
+            try:
+                field, value = line.split('=', 1)
+            except ValueError:
+                continue
+
+            # each translatable or translated field
+            for target_field in DESKTOP_FILE_FIELDS:
+                if not field.startswith(target_field):
+                    continue
+
+                # translated field
+                if field.startswith(f'{target_field}['):
+                    # remove translation
+                    content = content[:idx] + content[idx+1:]
+                    continue
+
+                # remember original string
+                to_translate[target_field] = value
+                continue
+
+                # PLAUSI
+                if field != target_field:
+                    raise RuntimeError(
+                        f'Unexpected situation. {target_field=} {field=} '
+                        f'{value=} {line=}'
+                    )
+
+        for field, value in to_translate.items():
+            print(f'{field=} {value=}')
+
+            translations = _get_translation_for_desktop_string(value)
+
+            if field == 'Comment':
+                _check_value_length(translations, field)
+
+            translations = [
+                f'{field}[{lang}]={translated}'
+                for lang, translated
+                in translations.items()
+            ]
+
+            content = content + translations
+
+    # ensure newline at end of file
+    content = content + ['\n']
+
+    desktop_fp.write_text('\n'.join(content), encoding='utf-8')
+
+
+def _check_value_length(translations, field):
+    """Debian GNU/Linux (lintian) limit the length of this field to 80 chars.
+    """
+    LIMIT = 79
+
+    for lang, val in translations.items():
+        if len(val) <= LIMIT:
+            continue
+
+        print(
+            f'WARNING: Length of {field}[{lang}] reached the '
+            f'limit of {LIMIT} and is {len(val)}. "{val}"'
+        )
+
+
+def _set_header(po_path: Path, spdx_base: str):
+    """Setup the header and comments header of the given po-file to the current
+    state.
+
+    """
+
+    pof = polib.pofile(po_path)
+
+    # Version string
+    pof.metadata['Project-Id-Version'] = f'{PACKAGE_NAME} {PACKAGE_VERSION}'
+
+    copyright = [DEFAULT_COPYRIGHT]
+
+    # Extract authors
+    e = pof.find(TRANSLATION_PLACEHOLDER_MSGID)
+    if e:
+        copyright = copyright + list(filter(
+            lambda val: len(val) > 0, e.msgstr.split('\n')
+        ))
+        for idx, centry in enumerate(copyright):
+            if not ('(c)' in centry or '©' in centry):
+                copyright[idx] = f'© {copyright[idx]}'
+
+    copyright = [
+        f'SPDX-FileCopyrightText: {centry}' for centry in copyright]
+
+    copyright = '\n'.join(copyright)
+
+    pof.header = f'{copyright}\n{spdx_base}\n{MISSING_TRANSLATORS_TXT}'
+
+    # Remove someday
+    try:
+        del pof.metadata['X-Launchpad-Export-Date']
+    except KeyError:
+        pass
+
+    pof.save()
+
 
 def check_existence():
     """Check for existence of essential files.
@@ -258,6 +507,18 @@ def check_syntax_of_po_files():
 
         return True
 
+    def _potential_harmful_strings(to_check):
+        """Check if the translated string contain harmful content.
+
+        URLs indicated by 'href' can be harmful if the string is used in a
+        QLabel with activated HTML interpretation.
+        """
+        if re.search('href', to_check, re.IGNORECASE):
+            print(f'CRITICAL - Potential harmful string: "{to_check}"')
+            return False
+
+        return True
+
     def _other_errors(to_check):
         """Check if there are any other errors that could be thrown via
         printing this string."""
@@ -320,18 +581,20 @@ def check_syntax_of_po_files():
 
     print('Checking syntax of po files…')
 
+    # collect translator-credit string
+    translators = {}
+
     # Each po file
     for po_path in all_po_files_in_local_dir():
         error_count = 0
         # Language code determined by po-filename
         lang_code = po_path.with_suffix('').name
 
-        # print(f'{lang_code}', end=' ')
-
         pof = polib.pofile(po_path)
 
         # Each translated entry
         for entry in pof.translated_entries():
+
             # Plural form?
             if entry.msgstr_plural or entry.msgid_plural:
                 # Ignoring plural form because this is to complex, not logical
@@ -339,6 +602,7 @@ def check_syntax_of_po_files():
                 continue
 
             if (not _curly_brackets_balanced(entry.msgstr)
+                    or not _potential_harmful_strings(entry.msgstr)
                     or not _other_errors(entry.msgstr)
                     or not _place_holders(entry.msgstr,
                                           entry.msgid,
@@ -346,10 +610,20 @@ def check_syntax_of_po_files():
                 print(f'\nSource string: {entry.msgid}\n')
                 error_count += 1
 
+            # translator string?
+            if entry.msgid == 'translator-credits-placeholder':
+                translators[languages.names[lang_code]['en']] \
+                    = entry.msgstr.split('\n')
+
         if error_count:
             print(f' {lang_code} >> {error_count} errors')
-        else:
-            print(f' {lang_code} >> OK')
+        # else:
+        #     print(f' {lang_code} >> OK')
+
+    translators = {
+        key: translators[key] for key in sorted(translators.keys())}
+    print('\nTRANSLATORS:')
+    print(json.dumps(translators, indent=4, ensure_ascii=False))
 
     print('')
 
@@ -359,6 +633,23 @@ def all_po_files_in_local_dir():
     return LOCAL_DIR.rglob('**/*.po')
 
 
+def all_desktop_files_in_qt_dir():
+    return sorted(GUI_DIR.glob('*.desktop'))
+
+
+def show_completeness_info(compl_dict, names_dict):
+    sorted_dict = dict(
+        sorted(
+            compl_dict.items(),
+            key=lambda items: items[1],
+            reverse=True
+        )
+    )
+    for code, completeness in sorted_dict.items():
+        lang = names_dict[code]['en']
+        print(f'{completeness:3} % - {lang} ({code})')
+
+
 def create_completeness_dict():
     """Create a simple dictionary indexed by language code and value that
     indicate the completeness of the translation in percent.
@@ -379,13 +670,10 @@ def create_completeness_dict():
     # "en" is the source language
     result['en'] = 100
 
-    # info
-    # print(json.dumps(result, indent=4))
-
     return result
 
 
-def create_languages_file():
+def create_languages_py_file():
     """Create the languages.py file containing language names and the
     completeness of their translation.
 
@@ -402,6 +690,9 @@ def create_languages_file():
 
     # the same with completeness dict
     compl_dict = create_completeness_dict()
+
+    show_completeness_info(compl_dict, names_dict)
+
     content.append('')
     content.append('')
     content.append('completeness = {')
@@ -477,7 +768,7 @@ def create_language_names_dict(language_codes: list) -> dict:
     result = {}
 
     for code in sorted(language_codes):
-        print(f'Processing language code "{code}"…')
+        # print(f'Processing language code "{code}"…')
 
         lang = babel.Locale.parse(code)
         result[code] = {}
@@ -549,13 +840,13 @@ def get_shortcut_groups() -> dict[str, list]:
         '&Backup',
         '&Restore',
         '&Help',
+        'Back In &Time',
         # Manage profiles dialog (tabs)
         '&General',
         '&Include',
         '&Exclude',
         '&Remove & Retention',
         '&Options',
-        'Back In &Time',
         'E&xpert Options',
     ]
 
@@ -573,14 +864,6 @@ def get_shortcut_groups() -> dict[str, list]:
             f'  Expected: {sorted(expect)}\n'
             f'      Real: {sorted(real)}')
 
-    # WORKAROUND
-    # This source string is not a translateble string but has a shortcut
-    # letter.
-    # Dev note: From point of view of the translators it might make sense
-    # making that string translatable also. But then we risk that our projects
-    # name is translated for real.
-    expect = ['Back In &Time'] + expect
-
     return {'mainwindow': expect[:4], 'manageprofile': expect[4:]}
 
 
@@ -651,7 +934,8 @@ def check_shortcuts():
                 print(err_msg)
 
 
-def get_spdx_metadata_lines() -> str:
+def get_spdx_metadata_lines(ignore_copyright: bool = False,
+                            without_comment_prefix: bool = False) -> str:
     """Extract the SPDX meta data lines from the current source file."""
     result = ''
 
@@ -663,15 +947,54 @@ def get_spdx_metadata_lines() -> str:
             if line.startswith('#!'):
                 continue
 
+            # ignore copyright
+            if ignore_copyright and 'SPDX-FileCopyrightText' in line:
+                continue
+
             # stop
             if line.startswith('"""') or line.startswith('import'):
                 break
 
-            result = result + line
-       
+            # remove comments prefix "# "
+            if without_comment_prefix and line.startswith('#'):
+                line = line[1:]
+
+            result = result + line.strip() + '\n'
+
     return result
 
 
+def _get_translation_for_desktop_string(value: str) -> dict[str, str]:
+    """Check all po files for a translation of 'value' and create a list
+    of the results fitting to a desktop file.
+
+    e.g.
+        GenericName[de]=Foo
+        GenericName[vi]=Bar
+
+    Returns:
+        A dictionary indexed by language code and the translation as value.
+    """
+    translations: dict[str, str] = {}
+
+    for po_path in LOCAL_DIR.rglob('**/*.po'):
+        po = polib.pofile(po_path)
+
+        entry = po.find(value)
+
+        # Nothing found or no translation
+        if entry is None or not entry.msgstr:
+            continue
+
+        # Translation finished?
+        if 'fuzzy' in entry.flags or entry.obsolete:
+            continue
+
+        translations[po_path.stem] = entry.msgstr
+
+    return translations
+
+
 if __name__ == '__main__':
     check_existence()
 
@@ -681,7 +1004,8 @@ if __name__ == '__main__':
     if 'source' in sys.argv:
         update_po_template()
         update_po_language_files('--remove-obsolete-entries' in sys.argv)
-        create_languages_file()
+        update_desktop_files()
+        create_languages_py_file()
         print(FIN_MSG)
         sys.exit()
 
@@ -690,7 +1014,7 @@ if __name__ == '__main__':
     if 'weblate' in sys.argv:
         update_from_weblate()
         check_syntax_of_po_files()
-        create_languages_file()
+        create_languages_py_file()
         print(FIN_MSG)
         sys.exit()
 
@@ -710,7 +1034,7 @@ if __name__ == '__main__':
           'Optional use --remove-obsolete-entries\n'
           '  weblate - Update the po files with translations from '
           'external translation service Weblate. (Download from Weblate)\n'
-          '  shortcut - Check po files for redundant keyboard shortcuts '
+          '  shortcuts - Check po files for redundant keyboard shortcuts '
           'using "&"\n'
           '  syntax - Check syntax of po files. (Also done via "weblate" '
           'command)')
